@@ -35,21 +35,29 @@ import pygame_menu.utils as _utils
 import pygame_menu.widgets as _widgets
 from pygame_menu.baseimage import BaseImage
 
+from pygame.version import vernum as pygame_vernum
 import copy
-import pygame
 
 
 class Theme(object):
     """
     Class defining the visual rendering of menus and widgets.
 
-    .. note:: All colors must be defined with a tuple of 3 or 4 numbers in the formats:
+    .. note::
 
-                - (R,G,B)
-                - (R,G,B,A)
+        All colors must be defined with a tuple of 3 or 4 numbers in the formats:
 
-            Red (R), Green (G) and Blue (B) must be numbers between 0 and 255.
-            A means the alpha channel (opacity), if 0 the color is transparent, 100 means opaque.
+            - (R,G,B)
+            - (R,G,B,A)
+
+        Red (R), Green (G) and Blue (B) must be numbers between 0 and 255.
+        A means the alpha channel (opacity), if 0 the color is transparent, 100 means opaque.
+
+    .. note::
+
+        Themes only modify visual behaviour of the Menu. For other options
+        like rows/columns, enabling or disabling overflow, position or menu
+        width/height see Menu parameters.
 
     :param background_color: Menu background color
     :type background_color: tuple, list, :py:class:`pygame_menu.baseimage.BaseImage`
@@ -107,12 +115,16 @@ class Theme(object):
     :type title_shadow_position: str
     :param widget_alignment: Widget default `alignment <https://pygame-menu.readthedocs.io/en/latest/_source/create_menu.html#widgets-alignment>`_
     :type widget_alignment: str
-    :param widget_background_color: Background color of a widget
+    :param widget_background_color: Background color of a widget, it can be a color or a BaseImage object. Background fills the entire widget + the padding
     :type widget_background_color: tuple, list, :py:class:`pygame_menu.baseimage.BaseImage`, None
+    :param widget_background_inflate: Inflate background in (x,y) in px. By default it uses the highlight margin. This parameter is visual only. For modifying widget size use padding instead
+    :type widget_background_inflate: tuple, list
     :param widget_font: Widget font path or name
     :type widget_font: str
     :param widget_font_antialias: Widget font renders with antialiasing
     :type widget_font_antialias: bool
+    :param widget_font_background_color: Widget font background color. By default it is None. If None the value will be the same as ``background_color`` if it's is a color object and if ``widget_font_background_color_from_menu`` is True and ``widget_background_color`` is None
+    :type widget_font_background_color: tuple, list, None
     :param widget_font_background_color_from_menu: Use menu background color as font background color, True by default in pygame v2
     :type widget_font_background_color_from_menu: bool
     :param widget_font_color: Color of the font
@@ -121,11 +133,11 @@ class Theme(object):
     :type widget_font_size: int
     :param widget_margin: Horizontal and vertical margin of each element in Menu (px). Default (0,10)
     :type widget_margin: tuple, list
-    :param widget_padding: Padding of the widget according to CSS rules. It can be a single digit, or a tuple of 2, 3 or 4 elements
+    :param widget_padding: Padding of the widget according to CSS rules. It can be a single digit, or a tuple of 2, 3 or 4 elements. Padding modifies widget width/height
     :type widget_padding: int, float, tuple, list
     :param widget_offset: X,Y axis offset of widgets within Menu (px) respect to top-left corner. If value less than 1 use percentage of width/height. Default (0,0). It cannot be negative values
     :type widget_offset: tuple, list
-    :param widget_selection_effect: Widget selection effect object
+    :param widget_selection_effect: Widget selection effect object. This is visual-only, the selection properties does not affect widget height/width
     :type widget_selection_effect: :py:class:`pygame_menu.widgets.core.Selection`
     :param widget_shadow: Indicate if a shadow is drawn on each widget
     :type widget_shadow: bool
@@ -138,93 +150,98 @@ class Theme(object):
     """
 
     def __init__(self, **kwargs):
-        
-        self.background_color = self._get(kwargs, 'background_color',
-                                          'color_image', (220, 220, 220))  # type: tuple
-        self.cursor_color = self._get(kwargs, 'cursor_color',
-                                      'color', (0, 0, 0))  # type: tuple
-        self.cursor_selection_color = self._get(kwargs, 'cursor_selection_color',
-                                                'color', (30, 30, 30, 120))  # type: tuple
-        self.focus_background_color = self._get(kwargs, 'focus_background_color',
-                                                'color', (0, 0, 0, 180))  # type: tuple
-        self.menubar_close_button = self._get(kwargs, 'menubar_close_button',
-                                              bool, True)  # type: bool
-        self.scrollarea_outer_margin = self._get(kwargs, 'scrollarea_outer_margin',
-                                                 'tuple2', (0, 0))  # type: tuple
-        self.scrollbar_color = self._get(kwargs, 'scrollbar_color',
-                                         'color', (220, 220, 220))  # type: tuple
-        self.scrollbar_shadow = self._get(kwargs, 'scrollbar_shadow',
-                                          bool, False)  # type: bool
-        self.scrollbar_shadow_color = self._get(kwargs, 'scrollbar_shadow_color',
-                                                'color', (0, 0, 0))  # type: bool
-        self.scrollbar_shadow_offset = self._get(kwargs, 'scrollbar_shadow_offset',
-                                                 (int, float), 2)  # type: (int, float)
-        self.scrollbar_shadow_position = self._get(kwargs, 'scrollbar_shadow_position',
-                                                   'position', pygame_menu.locals.POSITION_NORTHWEST)  # type: str
-        self.scrollbar_slider_color = self._get(kwargs, 'scrollbar_slider_color',
-                                                'color', (200, 200, 200))  # type: tuple
-        self.scrollbar_slider_pad = self._get(kwargs, 'scrollbar_slider_pad',
-                                              (int, float), 0)  # type: (int,float)
-        self.scrollbar_thick = self._get(kwargs, 'scrollbar_thick',
-                                         (int, float), 20)  # type: (int,float)
-        self.selection_color = self._get(kwargs, 'selection_color',
-                                         'color', (255, 255, 255))  # type: tuple
-        self.surface_clear_color = self._get(kwargs, 'surface_clear_color',
-                                             'color', (0, 0, 0))  # type: tuple
-        self.title_background_color = self._get(kwargs, 'title_background_color',
-                                                'color', (70, 70, 70))  # type: tuple
-        self.title_bar_style = self._get(kwargs, 'title_bar_style',
-                                         int, _widgets.MENUBAR_STYLE_ADAPTIVE)  # type: int
-        self.title_font = self._get(kwargs, 'title_font',
-                                    str, pygame_menu.font.FONT_OPEN_SANS)  # type: str
-        self.title_font_antialias = self._get(kwargs, 'title_font_antialias',
-                                              bool, True)  # type: bool
-        self.title_font_color = self._get(kwargs, 'title_font_color',
-                                          'color', (220, 220, 220))  # type: tuple
-        self.title_font_size = self._get(kwargs, 'title_font_size',
-                                         int, 40)  # type: int
-        self.title_offset = self._get(kwargs, 'title_offset',
-                                      'tuple2', (5, 0))  # type: tuple
-        self.title_shadow = self._get(kwargs, 'title_shadow',
-                                      bool, False)  # type: bool
-        self.title_shadow_color = self._get(kwargs, 'title_shadow_color',
-                                            'color', (0, 0, 0))  # type: tuple
-        self.title_shadow_offset = self._get(kwargs, 'title_shadow_offset',
-                                             (int, float), 2)  # type: (int,float)
-        self.title_shadow_position = self._get(kwargs, 'title_shadow_position',
-                                               'position', pygame_menu.locals.POSITION_NORTHWEST)  # type: str
-        self.widget_font = self._get(kwargs, 'widget_font',
-                                     str, pygame_menu.font.FONT_OPEN_SANS)  # type: str
-        self.widget_alignment = self._get(kwargs, 'widget_alignment',
-                                          'alignment', pygame_menu.locals.ALIGN_CENTER)  # type: str
-        self.widget_background_color = self._get(kwargs, 'widget_background_color',
-                                                 'color_image_none')  # type: (tuple, type(None))
-        self.widget_background_inflate = self._get(kwargs, 'background_inflate',
-                                                   'tuple2', (16, 8))  # type: tuple
-        self.widget_font_antialias = self._get(kwargs, 'widget_font_antialias',
-                                               bool, True)  # type: bool
+
+        # Set independant parameters
+        self.background_color = self._get(kwargs, 'background_color', 'color_image',
+                                          (220, 220, 220))  # type: tuple
+        self.cursor_color = self._get(kwargs, 'cursor_color', 'color',
+                                      (0, 0, 0))  # type: tuple
+        self.cursor_selection_color = self._get(kwargs, 'cursor_selection_color', 'color',
+                                                (30, 30, 30, 120))  # type: tuple
+        self.focus_background_color = self._get(kwargs, 'focus_background_color', 'color',
+                                                (0, 0, 0, 180))  # type: tuple
+        self.menubar_close_button = self._get(kwargs, 'menubar_close_button', bool,
+                                              True)  # type: bool
+        self.scrollarea_outer_margin = self._get(kwargs, 'scrollarea_outer_margin', 'tuple2',
+                                                 (0, 0))  # type: tuple
+        self.scrollbar_color = self._get(kwargs, 'scrollbar_color', 'color',
+                                         (220, 220, 220))  # type: tuple
+        self.scrollbar_shadow = self._get(kwargs, 'scrollbar_shadow', bool,
+                                          False)  # type: bool
+        self.scrollbar_shadow_color = self._get(kwargs, 'scrollbar_shadow_color', 'color',
+                                                (0, 0, 0))  # type: bool
+        self.scrollbar_shadow_offset = self._get(kwargs, 'scrollbar_shadow_offset', (int, float),
+                                                 2)  # type: (int, float)
+        self.scrollbar_shadow_position = self._get(kwargs, 'scrollbar_shadow_position', 'position',
+                                                   pygame_menu.locals.POSITION_NORTHWEST)  # type: str
+        self.scrollbar_slider_color = self._get(kwargs, 'scrollbar_slider_color', 'color',
+                                                (200, 200, 200))  # type: tuple
+        self.scrollbar_slider_pad = self._get(kwargs, 'scrollbar_slider_pad', (int, float),
+                                              0)  # type: (int,float)
+        self.scrollbar_thick = self._get(kwargs, 'scrollbar_thick', (int, float),
+                                         20)  # type: (int,float)
+        self.selection_color = self._get(kwargs, 'selection_color', 'color',
+                                         (255, 255, 255))  # type: tuple
+        self.surface_clear_color = self._get(kwargs, 'surface_clear_color', 'color',
+                                             (0, 0, 0))  # type: tuple
+        self.title_background_color = self._get(kwargs, 'title_background_color', 'color',
+                                                (70, 70, 70))  # type: tuple
+        self.title_bar_style = self._get(kwargs, 'title_bar_style', int,
+                                         _widgets.MENUBAR_STYLE_ADAPTIVE)  # type: int
+        self.title_font = self._get(kwargs, 'title_font', str,
+                                    pygame_menu.font.FONT_OPEN_SANS)  # type: str
+        self.title_font_antialias = self._get(kwargs, 'title_font_antialias', bool,
+                                              True)  # type: bool
+        self.title_font_color = self._get(kwargs, 'title_font_color', 'color',
+                                          (220, 220, 220))  # type: tuple
+        self.title_font_size = self._get(kwargs, 'title_font_size', int,
+                                         40)  # type: int
+        self.title_offset = self._get(kwargs, 'title_offset', 'tuple2',
+                                      (5, -1))  # type: tuple
+        self.title_shadow = self._get(kwargs, 'title_shadow', bool,
+                                      False)  # type: bool
+        self.title_shadow_color = self._get(kwargs, 'title_shadow_color', 'color',
+                                            (0, 0, 0))  # type: tuple
+        self.title_shadow_offset = self._get(kwargs, 'title_shadow_offset', (int, float),
+                                             2)  # type: (int,float)
+        self.title_shadow_position = self._get(kwargs, 'title_shadow_position', 'position',
+                                               pygame_menu.locals.POSITION_NORTHWEST)  # type: str
+        self.widget_font = self._get(kwargs, 'widget_font', str,
+                                     pygame_menu.font.FONT_OPEN_SANS)  # type: str
+        self.widget_alignment = self._get(kwargs, 'widget_alignment', 'alignment',
+                                          pygame_menu.locals.ALIGN_CENTER)  # type: str
+        self.widget_background_color = self._get(kwargs, 'widget_background_color', 'color_image_none',
+                                                 )  # type: (tuple, type(None))
+        self.widget_font_antialias = self._get(kwargs, 'widget_font_antialias', bool,
+                                               True)  # type: bool
+        self.widget_font_background_color = self._get(kwargs, 'widget_font_background_color', 'color_none',
+                                                      )  # type: tuple
         self.widget_font_background_color_from_menu = self._get(kwargs, 'widget_font_background_color_from_menu',
-                                                                bool, pygame.vernum[0] == 2)  # type: bool
-        self.widget_font_color = self._get(kwargs, 'widget_font_color',
-                                           'color', (70, 70, 70))  # type: tuple
-        self.widget_font_size = self._get(kwargs, 'widget_font_size',
-                                          int, 30)  # type: int
-        self.widget_margin = self._get(kwargs, 'widget_margin',
-                                       'tuple2', (0, 10))  # type: tuple
-        self.widget_padding = self._get(kwargs, 'widget_padding',
-                                        (int, float), 0)  # type: (int,float,tuple)
-        self.widget_offset = self._get(kwargs, 'widget_offset',
-                                       'tuple2', (0, 0))  # type: tuple
+                                                                bool, pygame_vernum[0] == 2)  # type: bool
+        self.widget_font_color = self._get(kwargs, 'widget_font_color', 'color',
+                                           (70, 70, 70))  # type: tuple
+        self.widget_font_size = self._get(kwargs, 'widget_font_size', int,
+                                          30)  # type: int
+        self.widget_margin = self._get(kwargs, 'widget_margin', 'tuple2',
+                                       (0, 10))  # type: tuple
+        self.widget_padding = self._get(kwargs, 'widget_padding', (int, float),
+                                        0)  # type: (int,float,tuple)
+        self.widget_offset = self._get(kwargs, 'widget_offset', 'tuple2',
+                                       (0, 0))  # type: tuple
         self.widget_selection_effect = self._get(kwargs, 'widget_selection_effect', _widgets.core.Selection,
                                                  _widgets.HighlightSelection())  # type: _widgets.core.Selection
-        self.widget_shadow = self._get(kwargs, 'widget_shadow',
-                                       bool, False)  # type: bool
-        self.widget_shadow_color = self._get(kwargs, 'widget_shadow_color',
-                                             'color', (0, 0, 0))  # type: tuple
-        self.widget_shadow_offset = self._get(kwargs, 'widget_shadow_offset',
-                                              (int, float), 2)  # type: (int,float)
-        self.widget_shadow_position = self._get(kwargs, 'widget_shadow_position',
-                                                'position', pygame_menu.locals.POSITION_NORTHWEST)  # type: str
+        self.widget_shadow = self._get(kwargs, 'widget_shadow', bool,
+                                       False)  # type: bool
+        self.widget_shadow_color = self._get(kwargs, 'widget_shadow_color', 'color',
+                                             (0, 0, 0))  # type: tuple
+        self.widget_shadow_offset = self._get(kwargs, 'widget_shadow_offset', (int, float),
+                                              2)  # type: (int,float)
+        self.widget_shadow_position = self._get(kwargs, 'widget_shadow_position', 'position',
+                                                pygame_menu.locals.POSITION_NORTHWEST)  # type: str
+
+        # Set dependant parameters
+        self.widget_background_inflate = self._get(kwargs, 'background_inflate', 'tuple2',
+                                                   self.widget_selection_effect.get_xy_margin())  # type: tuple
 
         # Upon this, no more kwargs should exist, raise exception if there's more
         for invalid_keyword in kwargs.keys():
@@ -243,8 +260,9 @@ class Theme(object):
         """
 
         # Size asserts
-        assert self.scrollbar_thick > 0, 'scrollbar thickness must be greater than zero'
         assert self.scrollbar_shadow_offset > 0, 'scrollbar shadow offset must be greater than zero'
+        assert self.scrollbar_slider_pad >= 0, 'slider pad must be equal or greater tham zero'
+        assert self.scrollbar_thick > 0, 'scrollbar thickness must be greater than zero'
         assert self.title_font_size > 0, 'title font size must be greater than zero'
         assert self.widget_font_size > 0, 'widget font size must be greater than zero'
         assert self.widget_shadow_offset > 0, 'widget shadow offset must be greater than zero'
@@ -263,6 +281,7 @@ class Theme(object):
         self.title_font_color = self._format_opacity(self.title_font_color)  # type: tuple
         self.title_shadow_color = self._format_opacity(self.title_shadow_color)  # type: tuple
         self.widget_background_color = self._format_opacity(self.widget_background_color)  # type: tuple
+        self.widget_font_background_color = self._format_opacity(self.widget_font_background_color)  # type: tuple
         self.widget_font_color = self._format_opacity(self.widget_font_color)  # type: tuple
 
         # List to tuple
@@ -277,9 +296,9 @@ class Theme(object):
 
         # Check sizes
         assert self.scrollarea_outer_margin[0] >= 0 and self.scrollarea_outer_margin[1] >= 0, \
-            'scrollarea outer margin must be greater or equal than zero'
+            'scrollarea outer margin must be equal or greater than zero'
         assert self.widget_offset[0] >= 0 and self.widget_offset[1] >= 0, \
-            'widget offset must be greater or equal than zero'
+            'widget offset must be equal or greater than zero'
 
         # Configs
         self.widget_selection_effect.set_color(self.selection_color)
